@@ -27,28 +27,30 @@
 #include "flist.h"
 /*----------------------------------------------------------------------------*/
 /**
- * @brief  Select folder dialog.
+ * @fn  char * add_images_folder_dialog (GtkWindow *gw_parent)
+ * @brief     Select folder dialog.
+ * @param[in] gw_parent  Dialog parent widget
+ * @return    Foler path or NULL.
  *
- * @param[in]  gw_parent  Dialog parent widget
- * @return     Foler path or NULL.
+ * @fn  GSList * add_images_dialog (GtkWindow *gw_parent)
+ * @brief     Select images dialog.
+ * @param[in] gw_parent  Dialog parent widget
+ * @return    List with images.
+ *
+ * @fn  void message_dialog_error (GtkWindow  *gw_parent,
+ *                                 const char *s_message)
+ * @brief     Error message dialog.
+ * @param[in] gw_parent  Dialog parent widget
+ * @param[in] s_message  Message to show
+ * @return    none
  */
-char *add_images_folder_dialog (GtkWindow *gw_parent);
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Select images dialog.
- *
- * @param[in]  gw_parent  Dialog parent widget
- * @return     List with images.
- */
-GSList *add_images_dialog (GtkWindow *gw_parent);
+char   * add_images_folder_dialog (GtkWindow  *gw_parent);
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Error message dialog.
- *
- * @param[in]  gw_parent  Dialog parent widget
- * @param[in]  s_message  Message to show
- * @return     none
- */
-void message_dialog_error (GtkWindow *gw_parent, const char *s_message);
+GSList * add_images_dialog        (GtkWindow  *gw_parent);
+/*----------------------------------------------------------------------------*/
+void     message_dialog_error     (GtkWindow  *gw_parent,
+                                   const char *s_message);
 /*----------------------------------------------------------------------------*/
 #endif
+
